<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.0">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>정보...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>번역가</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>라이센스</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>SMPlayer 유투브%1 브라우저</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>버전: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>포터블 에디션</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>(%2를 사용해서) Qt %1 로 컴파일함</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>업데이트하려면 웹사이트를 방문하세요:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>많은 사람들이 번역에 공헌했습니다.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>여러분도 SMTube의 모국어 번역을 도와주실 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>%1 을 방문하고 번역 팀에 참여하세요.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Transifex 팀의 번역가를 알고 싶으면 여기를 클릭하세요</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="138"/>
        <source>Home</source>
        <translation>홈</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="141"/>
        <source>Navigation</source>
        <translation>네비게이션</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="149"/>
        <source>Zoom +</source>
        <translation>줌 +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="153"/>
        <source>Zoom -</source>
        <translation>줌 -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="157"/>
        <source>&amp;Quit</source>
        <translation>종료(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>&amp;Navigation</source>
        <translation>네비게이션(&amp;N)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="172"/>
        <source>&amp;View</source>
        <translation>보기</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="173"/>
        <source>Toolbar</source>
        <translation>툴바</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="177"/>
        <source>Statusbar</source>
        <translation>상태바</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="182"/>
        <source>&amp;Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="194"/>
        <source>&amp;Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="198"/>
        <source>&amp;Update YouTube playback support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="200"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="206"/>
        <source>&amp;About SMTube</source>
        <translation>SMTube 정보</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="331"/>
        <source>Download video using an external service</source>
        <translation>외부 서비스를 이용해 비디오 다운로드하기</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="332"/>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="578"/>
        <source>No video found</source>
        <translation>비디오를 찾을 수 없습니다</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>이 비디오의 URL을 찾지 못했습니다.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="610"/>
        <source>About...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="611"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="317"/>
        <source>Loading... %1%</source>
        <translation>불러오는 중... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="232"/>
        <source>In order to play YouTube videos, %1 needs the help of an external application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="233"/>
        <source>%1 can download and install this application for you.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="234"/>
        <source>It will be downloaded from the official website and installed as %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="235"/>
        <source>Would you like to proceed?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="239"/>
        <location filename="../codedownloader.cpp" line="242"/>
        <source>Install YouTube support?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>일반</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="178"/>
        <source>&amp;Players</source>
        <translation>재생기(&amp;P)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="226"/>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Up</source>
        <translation>위로</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>재생</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>선호 품질:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="152"/>
        <source>YouTube support application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="237"/>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="261"/>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="274"/>
        <source>A&amp;dd predefined players</source>
        <translation>미리 정의한 재생기 추가하기</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="310"/>
        <source>&amp;Interface</source>
        <translation>인터페이스(&amp;I)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="318"/>
        <source>&amp;Style:</source>
        <translation>스타일(&amp;S):</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="354"/>
        <source>Font:</source>
        <translation>글꼴:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="368"/>
        <source>C&amp;hange...</source>
        <translation>변경(&amp;H)...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>외부 서비스를 이용해 비디오를 다운로드하기(&amp;E)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="202"/>
        <source>Down</source>
        <translation>아래로</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="82"/>
        <source>Default</source>
        <translation>기본값</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="460"/>
        <source>yt-dlp (based on youtube-dl with improvements)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="478"/>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>파일이나 폴더를 선택하려면 클릭하세요</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>이 창에서 링크 열기</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="145"/>
        <source>Play &amp;audio with %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="154"/>
        <source>Play video with a &amp;web browser</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>재생기 편집하기</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>이름:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>실행 파일:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>변수:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>이 재생기는 비디오 사이트를 지원합니다</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>이 재생기는 온라인 TV를 재생할 수 있습니다(&amp;O)</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>선호 품질:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>메뉴에 추가하기:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>오디오</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>비디오와 오디오</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>기본</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../version.cpp" line="48"/>
        <source>%1 (revision %2) %3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../version.cpp" line="50"/>
        <source>%1 (revision %2)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>